==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/space/messages/ro/manage.php <==
<?php

return [
    '<strong>Security</strong> settings' => 'Securitate',
    'Actions' => 'Acțiuni',
    'Delete' => 'Șterge',
    'Members' => 'Membri',
    'Modules' => 'App',
    'Next' => 'Inainte',
    'Security' => 'Securitate',
    'Unarchive' => 'Dezarhivează',
    '-' => '',
    '<strong>Create</strong> new space' => '',
    '<strong>Manage</strong> members' => '',
    '<strong>Members</strong>' => '',
    '<strong>Space</strong> Modules' => '',
    '<strong>Space</strong> settings' => '',
    'Activated' => '',
    'Add <strong>Modules</strong>' => '',
    'Advanced access settings' => '',
    'Archive' => '',
    'Are you sure you want to remove this member.' => '',
    'Are you sure, that you want to delete this space? All published content will be removed!' => '',
    'Are you sure? *ALL* module data for this space will be deleted!' => '',
    'As owner of this space you can transfer this role to another administrator in space.' => '',
    'Cancel Membership' => '',
    'Choose if new content should be public or private by default' => '',
    'Choose the kind of membership you want to provide for this workspace.' => '',
    'Choose the security level for this workspace to define the visibleness.' => '',
    'Configure' => '',
    'Currently there are no modules available for this space!' => '',
    'Disable' => '',
    'Don\'t receive notifications for new content' => '',
    'Enable' => '',
    'Enhance this space with modules.' => '',
    'Hide posts on dashboard' => '',
    'Invited By' => '',
    'Owner' => '',
    'Pending Approvals' => '',
    'Pending Invites' => '',
    'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
    'Please type the name of the space to proceed.' => '',
    'Receive Notifications for new content' => '',
    'Remove from space' => '',
    'Role' => '',
    'Show all' => '',
    'Show posts on dashboard' => '',
    'Space name' => '',
    'Space owner' => '',
    'Stream (Default)' => '',
    'The url contains illegal characters!' => '',
    'This option will hide new content from this space at your dashboard' => '',
    'This option will show new content from this space at your dashboard' => '',
    'Transfer ownership' => '',
    'e.g. example for {baseUrl}/s/example' => '',
    'never' => '',
    'the default start page of this space for members' => '',
    'the default start page of this space for visitors' => '',
];

==> humhub-1.12.0.tar.gz: humhub-1.12.0/protected/humhub/modules/space/messages/ro/manage.php <==
<?php

return [
    '<strong>Security</strong> settings' => 'Securitate',
    'Actions' => 'Acțiuni',
    'Delete' => 'Șterge',
    'Members' => 'Membri',
    'Modules' => 'App',
    'Next' => 'Inainte',
    'Security' => 'Securitate',
    'Unarchive' => 'Dezarhivează',
    '-' => '',
    '<strong>Create</strong> Space' => '',
    '<strong>Manage</strong> members' => '',
    '<strong>Members</strong>' => '',
    '<strong>Space</strong> Modules' => '',
    '<strong>Space</strong> settings' => '',
    'Activate' => '',
    'Add <strong>Modules</strong>' => '',
    'Advanced access settings' => '',
    'Archive' => '',
    'Are you sure you want to remove this member.' => '',
    'Are you sure, that you want to delete this space? All published content will be removed!' => '',
    'As owner of this space you can transfer this role to another administrator in space.' => '',
    'Cancel Membership' => '',
    'Choose if new content should be public or private by default' => '',
    'Choose the kind of membership you want to provide for this workspace.' => '',
    'Choose the modules you want to use for this Space. If you are undecided, you can also activate them later on via the Space settings.' => '',
    'Choose the modules you want to use for this Space. In order for the modules to be available to you here, they must have been previously installed by administrators of the network using the admin panel. If you cannot deactivate individual modules, it is because they have been set as the default for the entire network.' => '',
    'Choose the security level for this workspace to define the visibleness.' => '',
    'Currently there are no modules available for this space!' => '',
    'Don\'t receive notifications for new content' => '',
    'Hide posts on dashboard' => '',
    'Invited By' => '',
    'Owner' => '',
    'Pending Approvals' => '',
    'Pending Invites' => '',
    'Permissions are assigned to different user-roles. To edit a permission, select the user-role you want to edit and change the drop-down value of the given permission.' => '',
    'Please type the name of the space to proceed.' => '',
    'Receive Notifications for new content' => '',
    'Remove from space' => '',
    'Role' => '',
    'Show all' => '',
    'Show posts on dashboard' => '',
    'Space name' => '',
    'Space owner' => '',
    'Stream (Default)' => '',
    'The url contains illegal characters!' => '',
    'This option will hide new content from this space at your dashboard' => '',
    'This option will show new content from this space at your dashboard' => '',
    'Transfer ownership' => '',
    'e.g. example for {baseUrl}/s/example' => '',
    'never' => '',
    'the default start page of this space for members' => '',
    'the default start page of this space for visitors' => '',
];
